/**
 * Hook to memoize a value based on JSON equality instead of reference equality.
 * Prevents unnecessary re-renders when data hasn't actually changed.
 */
export declare function useJsonMemo<T>(value: T): T;
//# sourceMappingURL=memo.d.ts.map